==> workflow-designer-plugin-6.2.0.5.jar: js/views/statuses/InitialStatusView.js <==
(function (Backbone) {
    /**
     * @name JIRA.WorkflowDesigner.InitialStatusView
     * @class The representation of the initial status ("Create") on the designer canvas.
     */
    Backbone.define("JIRA.WorkflowDesigner.InitialStatusView", JIRA.WorkflowDesigner.BaseStatusView.extend(
    /** @lends JIRA.WorkflowDesigner.InitialStatusView# */
    {
        /**
         * Creates the figure
         *
         * @returns {draw2d.shape.basic.Circle}
         * @private
         */
        _createFigure: function () {
            var figure, fill;

            figure = this._figure = new draw2d.shape.basic.Circle(30);
            figure.setBackgroundColor("#C0C0C0");
            figure.setStroke(0);
            figure.setSelectable(false);
            figure.snapToGeometry = true;

            fill = this._fill = new draw2d.shape.basic.Circle(30);
            fill.onMouseEnter = _.bind(this.trigger, this, "highlight");
            fill.onMouseLeave = _.bind(this.trigger, this, "unhighlight");
            fill.setBackgroundColor("#C0C0C0");
            fill.setStroke(0);

            figure.addFigure(fill, new draw2d.layout.locator.CenterLocator(figure));
            this._canvas.addFigure(figure);

            JIRA.WorkflowDesigner.Draw2DUtilities.setCursor(fill, "move");
            this._addPort();
            this._positionFigure();
            return figure;
        },

        /**
         * Adds a port to the figure
         *
         * @private
         */
        _addPort: function () {
            var direction = JIRA.WorkflowDesigner.Direction.DOWN,
                locator;

            this.port = this._createPort({
                connectionDirection: direction
            });

            locator = new JIRA.WorkflowDesigner.Layout.Locator.PositionOnParentBoundsLocator({
                parent: this._figure,
                side: direction,
                bias: 0.5
            });

            this._figure.addPort(this.port, locator);
        },

        /**
         * @returns {draw2d.geo.Rectangle} The view's bounding box.
         */
        getBoundingBox: function () {
            return this._figure.getBoundingBox();
        },

        /**
         * @return {draw2d.Port[]} The view's ports.
         */
        getPorts: function () {
            return [this.port];
        },

        /**
         * @return {boolean} Whether the view is selected.
         */
        isSelected: function () {
            return false;
        }
    }));
}(JIRA.WorkflowDesigner.Backbone));

==> workflow-designer-plugin-7.3.6.jar: js/views/statuses/InitialStatusView.js <==
define("workflow-designer/initial-status-view", [
    "workflow-designer/draw2d-utilities",
    "workflow-designer/layout/locator/position-on-parent-bounds-locator",
    "workflow-designer/base-status-view",
    "workflow-designer/direction",
    "workflow-designer/draw-2d",
    "workflow-designer/underscore"
], function(
    Draw2DUtilities,
    PositionOnParentBoundsLocator,
    BaseStatusView,
    Direction,
    draw2d,
    _
) {
    /**
     * @name JIRA.WorkflowDesigner.InitialStatusView
     * @class The representation of the initial status ("Create") on the designer canvas.
     */
    return BaseStatusView.extend(
    /** @lends JIRA.WorkflowDesigner.InitialStatusView# */
    {
        /**
         * Creates the figure
         *
         * @returns {draw2d.shape.basic.Circle}
         * @private
         */
        _createFigure: function () {
            var figure, fill;

            figure = this._figure = new draw2d.shape.basic.Circle(30);
            figure.setBackgroundColor("#C0C0C0");
            figure.setStroke(0);
            figure.setSelectable(false);
            figure.snapToGeometry = true;

            fill = this._fill = new draw2d.shape.basic.Circle(30);
            fill.onMouseEnter = _.bind(this.trigger, this, "highlight");
            fill.onMouseLeave = _.bind(this.trigger, this, "unhighlight");
            fill.setBackgroundColor("#C0C0C0");
            fill.setStroke(0);

            figure.addFigure(fill, new draw2d.layout.locator.CenterLocator(figure));
            this._canvas.addFigure(figure);

            Draw2DUtilities.setCursor(fill, "move");
            this._addPort();
            this._positionFigure();
            return figure;
        },

        /**
         * Adds a port to the figure
         *
         * @private
         */
        _addPort: function () {
            var direction = Direction.DOWN,
                locator;

            this.port = this._createPort({
                connectionDirection: direction
            });

            locator = new PositionOnParentBoundsLocator({
                parent: this._figure,
                side: direction,
                bias: 0.5
            });

            this._figure.addPort(this.port, locator);
        },

        /**
         * @returns {draw2d.geo.Rectangle} The view's bounding box.
         */
        getBoundingBox: function () {
            return this._figure.getBoundingBox();
        },

        /**
         * @return {draw2d.Port[]} The view's ports.
         */
        getPorts: function () {
            return [this.port];
        },

        /**
         * @return {boolean} Whether the view is selected.
         */
        isSelected: function () {
            return false;
        },

        /**
         * Renders the status view
         *
         * @returns {JIRA.WorkflowDesigner.InitialStatusView} this
         */
        render: function () {
            BaseStatusView.prototype.render.apply(this, arguments);
            this._positionFigure();
            return this;
        }
    });
});

AJS.namespace("JIRA.WorkflowDesigner.InitialStatusView", null, require("workflow-designer/initial-status-view"));
